@@ -24,8 +24,17 @@
 #ifndef _UPNP_CONNMGR_H
 #define _UPNP_CONNMGR_H
 
+#include <glib.h>
+
+typedef struct mime_type_filters_t
+{
+	GSList* allowed_roots;
+	GSList* removed_types;
+	GSList* added_types;
+} mime_type_filters_t;
+
 struct service *upnp_connmgr_get_service(void);
-int connmgr_init(const char* filter);
+int connmgr_init(const char* mime_filter);
 
 void register_mime_type(const char *mime_type);
 
